@@ -70,15 +70,15 @@ NNS.ARMA <- function(variable,
                      ncores = NULL){
 
   if(intervals && is.numeric(seasonal.factor)){
-      stop('Hmmm...Seems you have "intervals" and "seasonal.factor" selected.  Please set "intervals=F" or "seasonal.factor=F"')
+      stop('Hmmm...Seems you have "intervals" and "seasonal.factor" selected.  Please set "intervals = FALSE" or "seasonal.factor = FALSE"')
   }
 
   if(intervals && seasonal.factor){
-      stop('Hmmm...Seems you have "intervals" and "seasonal.factor" selected.  Please set "intervals=F" or "seasonal.factor=F"')
+      stop('Hmmm...Seems you have "intervals" and "seasonal.factor" selected.  Please set "intervals = FALSE" or "seasonal.factor = FALSE"')
   }
 
   if(is.numeric(seasonal.factor) && dynamic){
-      stop('Hmmm...Seems you have "seasonal.factor" specified and "dynamic==TRUE".  Nothing dynamic about static seasonal factors!  Please set "dynamic=F" or "seasonal.factor=F"')
+      stop('Hmmm...Seems you have "seasonal.factor" specified and "dynamic = TRUE".  Nothing dynamic about static seasonal factors!  Please set "dynamic = FALSE" or "seasonal.factor = FALSE"')
   }
 
 
@@ -169,9 +169,9 @@ NNS.ARMA <- function(variable,
               M <- t(1)
           } else {
               if(is.null(best.periods)){
-                  M<- seas.matrix$all.periods
+                  M <- seas.matrix$all.periods
               } else {
-              M<- seas.matrix$all.periods[1 : best.periods, ]
+              M <- seas.matrix$all.periods[1 : best.periods, ]
               }
           }
 
