@@ -19,7 +19,7 @@ factor_2_dummy <- function(x){
 }
 
 ### Factor to dummy variable FULL RANK
-factor_2_dummy_FR = function(x){
+factor_2_dummy_FR <- function(x){
   if(class(x) == "factor"){
     output <- model.matrix(~x -1, x)
   } else {
