@@ -141,28 +141,99 @@ NNS.stack <- function(IVs.train,
             nns.cv.1[1] <- -Inf
         }
 
-        for(i in 1:(2*n)){
-            if(status){
-                message("Current NNS.reg(... , n.best = ", i ," ) Iterations Remaining = " ,(2*n)-i," ","\r",appendLF=TRUE)
+
+
+
+        if(objective=='min'){
+
+            predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = 1, order=order, ncores = ncores)$Point.est
+
+            first.cv <- eval(obj.fn)
+
+            predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = l, order=order, ncores = ncores)$Point.est
+
+            last.cv <- eval(obj.fn)
+
+            i <- 1
+            j <- 1
+            while(last.cv<first.cv){
+
+                predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = max(1,round(l/(2*i))), order=order, ncores = ncores)$Point.est
+
+                last.cv <- eval(obj.fn)
+
+                predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = (2^j), order=order, ncores = ncores)$Point.est
+
+                first.cv <- eval(obj.fn)
+                begin.range <- (2^j)
+
+                end.range <- max(1,round(l/(2*i)))
+                if(begin.range>end.range) break
+                i <- i + 1
+                j <- j + 1
+
+
             }
 
-            predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = i, order=order, ncores = ncores)$Point.est
+            cv.range <- sort(round(max(1,2^(j-1))):round(l/max(1,(2*(i-1)))))
 
-            nns.cv.1[i+1] <- eval(obj.fn)
+        } else {
+
+
+          predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = 1, order=order, ncores = ncores)$Point.est
+
+          first.cv <- eval(obj.fn)
+
+          predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = l, order=order, ncores = ncores)$Point.est
+
+          last.cv <- eval(obj.fn)
+
+          i <- 1
+          j <- 1
+          while(last.cv<first.cv){
+            predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = max(1,round(l/(2*i))), order=order, ncores = ncores)$Point.est
+
+            last.cv <- eval(obj.fn)
+
+            predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = (2^j), order=order, ncores = ncores)$Point.est
+
+            first.cv <- eval(obj.fn)
+            begin.range <- (2^j)
+
+            end.range <- max(1,round(l/(2*i)))
+            if(begin.range>end.range) break
+            i <- i + 1
+            j <- j + 1
+          }
+
+            cv.range <- sort(round(max(1,2^(j-1))):round(l/max(1,(2*(i-1)))))
+        }
+
+
+        for(item in cv.range){
+            i <- which(item==cv.range)
+            if(status){
+                message("Current NNS.reg(... , n.best = ", item ," ) Max Iterations Remaining = " ,tail(cv.range,1)-item," ","\r",appendLF=TRUE)
+            }
+
+            predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, n.best = item, order=order, ncores = ncores)$Point.est
+
+####NOT 0 [i+0]
+            nns.cv.1[i+0] <- eval(obj.fn)
             if(i > 1){
-                if(objective=='min' && nns.cv.1[i]>nns.cv.1[i-1]){ break }
-                if(objective=='max' && nns.cv.1[i]<nns.cv.1[i-1]){ break }
+                if(objective=='min' && nns.cv.1[i]>=nns.cv.1[i-1]){ break }
+                if(objective=='max' && nns.cv.1[i]<=nns.cv.1[i-1]){ break }
             }
         }
 
         test.set.1 <- test.set[rev(order(abs(predicted - actual)))]
 
         if(objective=='min'){
-            k <- which.min(na.omit(nns.cv.1))-1
-            nns.cv.1 <- min(na.omit((nns.cv.1)))
+            k <- cv.range[which.min(na.omit(nns.cv.1))-0]
+            nns.cv.1 <- which.min(na.omit(nns.cv.1))
         } else {
-            k <- which.max(na.omit(nns.cv.1))-1
-            nns.cv.1 <- max(na.omit((nns.cv.1)))
+            k <- cv.range[which.max(na.omit(nns.cv.1))-0]
+            nns.cv.1 <- which.max(na.omit(nns.cv.1))
         }
 
 
@@ -205,7 +276,7 @@ NNS.stack <- function(IVs.train,
 
         for(i in 2:length(var.cutoffs)){
             if(status){
-                message("Current NNS.reg(... , threshold = ", var.cutoffs[i] ," ) Iterations Remaining = " ,length(var.cutoffs)-i," ","\r",appendLF=TRUE)
+                message("Current NNS.reg(... , threshold = ", var.cutoffs[i] ," ) Max Iterations Remaining = " ,length(var.cutoffs)-i," ","\r",appendLF=TRUE)
             }
 
             predicted <- NNS.reg(CV.IVs.train, CV.DV.train, point.est = CV.IVs.test, plot = FALSE, residual.plot = FALSE, dim.red.method = dim.red.method, threshold = var.cutoffs[i], order=order, ncores = ncores)$Point.est
